@@ -8,11 +8,14 @@ __all__ = (
 
 class ToggleIcon(Widget):
 
-    icon = String(default="heart", help="""
-        The name of the icon to display.""")
-
     active_icon = String(default="", help="""
         The name of the icon to display when toggled.""")
 
+    icon = String(default="heart", help="""
+        The name of the icon to display.""")
+
+    size = String(default="1em", help="""
+        The size of the icon as a valid CSS font-size.""")
+
     value = Bool(default=False, help="""
         Whether the icon is toggled on or off.""")
