@@ -4,21 +4,20 @@ import pytest
 
 import panel as pn
 
-from panel.io.server import serve
-from panel.tests.util import serve_panel_widget
+from panel.tests.util import serve_component, wait_until
 from panel.util import parse_query
 from panel.widgets import FloatSlider, RangeSlider, TextInput
 
 pytestmark = pytest.mark.ui
 
 
-def verify_document_location(expected_location, actual_location):
+def verify_document_location(expected_location, page):
     for param in expected_location:
-        assert param in actual_location
-        assert actual_location[param] == expected_location[param]
+        wait_until(lambda: param in page.evaluate('() => document.location'), page)
+        wait_until(lambda: page.evaluate('() => document.location')[param] == expected_location[param], page)
 
 
-def test_set_url_params_update_document(page, port):
+def test_set_url_params_update_document(page):
     def app():
         """Simple app to set url by widgets' values"""
         w1 = FloatSlider(name='Slider', start=0, end=10)
@@ -43,8 +42,7 @@ def test_set_url_params_update_document(page, port):
         pn.state.onload(cb)
         return widgets
 
-    serve_panel_widget(page, port, app)
-    page.wait_for_timeout(500)
+    _, port = serve_component(page, app)
 
     expected_location = {
         'protocol': 'http:',
@@ -54,16 +52,15 @@ def test_set_url_params_update_document(page, port):
         'hash': '',
         'reload': None
     }
-    actual_location = page.evaluate('() => document.location')
-    verify_document_location(expected_location, actual_location)
-    assert parse_query(actual_location['search']) == {
+    verify_document_location(expected_location, page)
+    wait_until(lambda: parse_query(page.evaluate('() => document.location')['search']) == {
         'range_value': [1, 2],
         'slider_value': 2,
         'text_value': 'Simple Text'
-    }
+    }, page)
 
 
-def test_set_hash_update_documment(page, port):
+def test_set_hash_update_document(page):
     def app():
         """simple app to set hash at onload"""
         widget = TextInput(name='Text')
@@ -74,8 +71,7 @@ def test_set_hash_update_documment(page, port):
         pn.state.onload(cb)
         return widget
 
-    serve_panel_widget(page, port, app)
-    page.wait_for_timeout(200)
+    _, port = serve_component(page, app)
 
     expected_location = {
         'href': f'http://localhost:{port}/#123',
@@ -87,11 +83,10 @@ def test_set_hash_update_documment(page, port):
         'hash': '#123',
         'reload': None
     }
-    actual_location = page.evaluate('() => document.location')
-    verify_document_location(expected_location, actual_location)
+    verify_document_location(expected_location, page)
 
 
-def test_set_document_location_update_state(page, port):
+def test_set_document_location_update_state(page):
     widget = TextInput(name='Text')
 
     def app():
@@ -106,10 +101,7 @@ def test_set_document_location_update_state(page, port):
         pn.state.onload(cb)
         return widget
 
-    serve(app, port=port, threaded=True, show=False)
-    time.sleep(0.2)
-    page.goto(f"http://localhost:{port}/?text_value=Text+Value")
-    page.wait_for_timeout(200)
+    serve_component(page, app, suffix="/?text_value=Text+Value")
 
     # confirm value of the text input widget
-    assert widget.value == 'Text Value'
+    wait_until(lambda: widget.value == 'Text Value', page)
